@@ -83,15 +83,19 @@ ION_API_EXPORT void        ion_alloc_free      (void *ptr);
 
 // force aligned allocations
 #ifndef ALLOC_ALIGNMENT
-#define ALLOC_ALIGNMENT 4
+#if __STDC_VERSION__ >= 201112L
+#include <stdalign.h>
+#include <stddef.h>
+#define ALLOC_ALIGNMENT (alignof(max_align_t))
+#else
+#define ALLOC_ALIGNMENT 16
+#endif
+#elif ((ALLOC_ALIGNMENT) & ((ALLOC_ALIGNMENT)-1)) != 0
+#error Invalid ALLOC_ALIGNMENT. Must be a power of 2.
 #endif
     
 #define ALIGN_MASK ((ALLOC_ALIGNMENT)-1)
     
-#if ((ALLOC_ALIGNMENT) & ALIGN_MASK) != 0
-#error Invalid ALLOC_ALIGNMENT. Must be a power of 2.
-#endif
-    
 #define ALIGN_SIZE(size) ((((size_t)(size)) + ALIGN_MASK) & ~ALIGN_MASK)
 #define ALIGN_PTR(ptr) ALIGN_SIZE(ptr)
 
@@ -108,8 +112,8 @@ struct _ion_allocation_chain
     // user bytes follow this header, though there may be some unused bytes here for alignment purposes
 };
 
-#define ION_ALLOC_BLOCK_TO_USER_PTR(block) ((BYTE*)ALIGN_PTR(((BYTE*)(block)) + sizeof(ION_ALLOCATION_CHAIN)))
-#define ION_ALLOC_USER_PTR_TO_BLOCK(ptr)   ((ION_ALLOCATION_CHAIN *)(((BYTE*)(ptr)) - sizeof(ION_ALLOCATION_CHAIN)))
+#define ION_ALLOC_BLOCK_TO_USER_PTR(block) ((BYTE*)ALIGN_PTR(((BYTE*)(block)) + ALIGN_SIZE(sizeof(ION_ALLOCATION_CHAIN))))
+#define ION_ALLOC_USER_PTR_TO_BLOCK(ptr)   ((ION_ALLOCATION_CHAIN *)(((BYTE*)(ptr)) - ALIGN_SIZE(sizeof(ION_ALLOCATION_CHAIN))))
 
 
 #ifdef MEM_DEBUG
@@ -127,48 +131,6 @@ typedef struct _ion_allocation_chain DBG_ION_ALLOCATION_CHAIN;
 #endif
 
 
-//
-//  structures and functions for the ion allocation page pool
-//  this is a list of free pages which are used by the various
-//  pools created by the Ion routines on behalf of the various
-//  objects, such as the reader, writer, or catalog.
-//
-//  THIS IS NOT THREAD SAFE - (which could be corrected)
-//
-
-typedef struct _ion_alloc_page      ION_ALLOC_PAGE;
-typedef struct _ion_alloc_page_list ION_ALLOC_PAGE_LIST;
-
-struct _ion_alloc_page
-{
-    ION_ALLOC_PAGE *next;
-};
-
-struct _ion_alloc_page_list
-{
-    SIZE            page_size;
-    int             page_count;
-    int             free_page_limit;
-    ION_ALLOC_PAGE *head;
-};
-
-#define ION_ALLOC_PAGE_POOL_NO_LIMIT           (-1)
-#define ION_ALLOC_PAGE_POOL_DEFAULT_LIMIT      (16)
-#define ION_ALLOC_PAGE_MIN_SIZE                (ALIGN_SIZE(sizeof(ION_ALLOCATION_CHAIN)))
-#define ION_ALLOC_PAGE_POOL_DEFAULT_PAGE_SIZE  (DEFAULT_BLOCK_SIZE)
-#define ION_ALLOC_PAGE_POOL_PAGE_SIZE_NONE     (-1)
-
-GLOBAL THREAD_LOCAL_STORAGE ION_ALLOC_PAGE_LIST g_ion_alloc_page_list
-#ifdef INIT_STATICS
-= { ION_ALLOC_PAGE_POOL_DEFAULT_PAGE_SIZE, 0, ION_ALLOC_PAGE_POOL_DEFAULT_LIMIT, NULL }
-#endif
-;
-
-ION_API_EXPORT void             ion_initialize_page_pool    (SIZE page_size, int free_page_limit);
-ION_API_EXPORT void             ion_release_page_pool       (void);
-
-ION_ALLOC_PAGE *_ion_alloc_page              (void);
-void            _ion_release_page            (ION_ALLOC_PAGE *page);
 
 void *_ion_alloc_owner     (SIZE len);
 void *_ion_alloc_with_owner(hOWNER owner, SIZE length);
