@@ -565,13 +565,16 @@ iERR _ion_reader_binary_validate_symbol_token(ION_READER *preader, SID sid)
 {
     iENTER;
     ION_SYMBOL_TABLE *symbol_table;
+    SID max_id;
+
     ASSERT(preader);
 
     symbol_table = preader->_current_symtab;
     if (!symbol_table) {
         IONCHECK(ion_symbol_table_get_system_table(&symbol_table, ION_SYSTEM_VERSION));
     }
-    if (sid <= UNKNOWN_SID || sid > symbol_table->max_id) {
+    IONCHECK(_ion_symbol_table_get_max_sid_helper(symbol_table, &max_id));
+    if (sid <= UNKNOWN_SID || sid > max_id) {
         FAILWITH(IERR_INVALID_SYMBOL);
     }
     iRETURN;
@@ -1006,7 +1009,17 @@ iERR _ion_reader_binary_read_int64(ION_READER *preader, int64_t *p_value)
     IONCHECK(ion_binary_read_uint_64(preader->istream, len, &unsignedInt64));
 
     is_negative = (tid == TID_NEG_INT)? TRUE: FALSE;
-    IONCHECK(cast_to_int64(unsignedInt64, is_negative, p_value));
+
+    {
+        iERR cast_result = cast_to_int64(unsignedInt64, is_negative, p_value);
+
+        // if an error is thrown reset reader stream's current pointer to the beginning of current value again
+        if (cast_result != IERR_OK) {
+            preader->istream->_curr -= len;
+            FAILWITH(cast_result);
+        }
+    }
+
     if (is_negative && *p_value == 0) {
         FAILWITH(IERR_INVALID_BINARY);
     }
