@@ -232,6 +232,7 @@ iERR _ion_writer_write_bool_helper(ION_WRITER *pwriter, BOOL value);
 iERR _ion_writer_write_int64_helper(ION_WRITER *pwriter, int64_t value);
 iERR _ion_writer_write_ion_int_helper(ION_WRITER *pwriter, ION_INT *value);
 iERR _ion_writer_write_mixed_int_helper(ION_WRITER *pwriter, ION_READER *preader);
+iERR _ion_writer_write_float_helper(ION_WRITER *pwriter, float value);
 iERR _ion_writer_write_double_helper(ION_WRITER *pwriter, double value);
 iERR _ion_writer_write_decimal_helper(ION_WRITER *pwriter, decQuad *value);
 iERR _ion_writer_write_ion_decimal_helper(ION_WRITER *pwriter, ION_DECIMAL *value);
@@ -330,6 +331,7 @@ iERR _ion_writer_binary_write_typed_null(ION_WRITER *pwriter, ION_TYPE type);
 iERR _ion_writer_binary_write_bool(ION_WRITER *pwriter, BOOL value);
 iERR _ion_writer_binary_write_int64(ION_WRITER *pwriter, int64_t value);
 iERR _ion_writer_binary_write_ion_int(ION_WRITER *pwriter, ION_INT *iint);
+iERR _ion_writer_binary_write_float(ION_WRITER *pwriter, float value);
 iERR _ion_writer_binary_write_double(ION_WRITER *pwriter, double value);
 iERR _ion_writer_binary_write_decimal_quad(ION_WRITER *pwriter, decQuad *value);
 iERR _ion_writer_binary_write_decimal_number(ION_WRITER *pwriter, decNumber *value);
